package org.logicaldoc.test.ws;

import java.io.IOException;

import junit.framework.TestCase;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.logicaldoc.core.searchengine.FulltextSearchOptions;
import com.logicaldoc.core.searchengine.HitImpl;
import com.logicaldoc.webservice.auth.AuthClient;
import com.logicaldoc.webservice.search.SearchClient;
import com.logicaldoc.webservice.search.WSSearchResult;

public class TestSearch extends TestCase {

	protected static Log log = LogFactory.getLog(TestFolder.class);
	
	String authEndpoint = "http://localhost:8080/services/Auth";
	String searchEndpoint = "http://localhost:8080/services/Search";
	
	private String sid;	

	public TestSearch(String arg0) {
		super(arg0);
	}

	protected void setUp() throws Exception {
		super.setUp();

		AuthClient authc = new AuthClient(authEndpoint);

		String username = "admin";
		String password = "admin";

		// Get session token
		sid = authc.login(username, password);
	}
	
	protected void tearDown() throws Exception {
		super.tearDown();
		
		AuthClient authc = new AuthClient(authEndpoint);
		authc.logout(sid);
		
		log.error("Logout completed successfully");
	}

	/**
	 * WARNING: because a search returns the results there must be documents indexed. 
	 * By default the documents via web-service are indexed in the
	 * background and then it is possible that the search returns no results. 
	 * If you want you can force the indexing from the GUI of LogicalDOC.
	 * 
	 * @throws IOException
	 */
	public void testSearch() throws IOException {

		SearchClient searchc = new SearchClient(searchEndpoint);

		String query = "Commercial";

		try {
			FulltextSearchOptions options = new FulltextSearchOptions();
			
            // This is the language of the document
            options.setLanguage("en");
            options.setExpression(query);
            // This is the language of the query
            options.setExpressionLanguage("en");

            // This is required and it is the maximum number of results that we want for this search
            options.setMaxHits(50);	
            
			WSSearchResult sr = searchc.find(sid, options);
			
			System.out.println("HITS: " + sr.getTotalHits());
			System.out.println("search completed in ms: " + sr.getTime());
			
			if (sr.getHits() != null) {
				for (HitImpl res : sr.getHits()) {
					System.out.println("title: " + res.getTitle());
					System.out.println("res.id: " + res.getDocId());
					System.out.println("res.summary: " + res.getSummary());
					System.out.println("res.size: " + res.getSize());
					System.out.println("res.date: " + res.getDate());
					System.out.println("res.type: " + res.getType());
					System.out.println("res.score: " + res.getScore());					
				}
			}

		} catch (Exception e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}
}
